@@ -20,8 +20,8 @@
     Boston, MA 02110-1301, USA.
 */
 
+#include <QtCore/QList>
 #include <QtCore/QString>
-#include <QtCore/QDebug>
 
 #include "tokenizer_p.h"
 #include "textbreaks_p.h"
@@ -34,9 +34,13 @@ class BreakTokenizerPrivate
 public:
     enum Type {Words, Sentences};
 
-    BreakTokenizerPrivate(Type s) :
-            breakFinder(new TextBreaks),
-            cacheValid(false), type(s), inAddress(false), ignoreUppercase(false)
+    BreakTokenizerPrivate(Type s)
+     : breakFinder(new TextBreaks)
+     , itemPosition(-1)
+     , cacheValid(false)
+     , type(s)
+     , inAddress(false)
+     , ignoreUppercase(false)
     {}
     ~BreakTokenizerPrivate() { delete breakFinder; }
     TextBreaks::Positions breaks() const;
@@ -183,7 +187,7 @@ QString WordTokenizer::buffer() const
 
 bool WordTokenizer::isUppercase(const QStringRef& word) const
 {
-    for (int i=0;i<word.length();i++)
+    for (int i=0;i<word.length();++i)
         if (word.at(i).isLetter() && !word.at(i).isUpper()) return false;
     return true;
 }
